@@ -1,7 +1,7 @@
 package Bencher::Scenarios::CloneModules;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2021-07-31'; # DATE
+our $VERSION = '0.050'; # VERSION
 
 1;
 # ABSTRACT: Scenarios related to data cloning modules
@@ -18,7 +18,7 @@ Bencher::Scenarios::CloneModules - Scenarios related to data cloning modules
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenarios::CloneModules (from Perl distribution Bencher-Scenarios-CloneModules), released on 2017-01-25.
+This document describes version 0.050 of Bencher::Scenarios::CloneModules (from Perl distribution Bencher-Scenarios-CloneModules), released on 2021-07-31.
 
 =head1 DESCRIPTION
 
@@ -52,9 +52,25 @@ feature.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords perlancar (@pc-office) Steven Haryanto (on PC, Jakarta)
+
+=over 4
+
+=item *
+
+perlancar (@pc-office) <perlancar@gmail.com>
+
+=item *
+
+Steven Haryanto (on PC, Jakarta) <stevenharyanto@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
